.. _swh-search:

.. include:: README.rst

It is kept in sync with :ref:`the main SWH storage <swh-storage>` via
:ref:`the SWH journal <swh-journal>`.

.. _CodeMeta: https://codemeta.github.io/


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cli
   query-language

Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

.. only:: standalone_package_doc

   Indices and tables
   ------------------

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
